@@ -1,6 +1,6 @@
 package Test::CheckDeps;
 {
-  $Test::CheckDeps::VERSION = '0.001';
+  $Test::CheckDeps::VERSION = '0.002';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -11,40 +11,38 @@ our @EXPORT_OK = qw/check_dependencies_opts/;
 our %EXPORT_TAGS = (all => [ @EXPORT, @EXPORT_OK ] );
 
 use CPAN::Meta;
+use CPAN::Meta::Check qw/check_requirements requirements_for/;
 use List::Util qw/first/;
 use Module::Metadata;
-use Test::More;
+use Test::Builder;
+
+my $builder = Test::Builder->new;
 
 sub check_dependencies { 
-	my $metafile = first { -e $_ } qw/MYMETA.json MYMETA.yml META.json META.yml/ or return fail("No META information provided\n");
+	my $metafile = first { -e $_ } qw/MYMETA.json MYMETA.yml META.json META.yml/ or return $builder->ok(0, "No META information provided\n");
 	my $meta = CPAN::Meta->load_file($metafile);
 	check_dependencies_opts($meta, $_, 'requires') for qw/configure build test runtime/;
+	check_dependencies_opts($meta, 'runtime', 'conflicts');
 	return;
 }
 
 sub check_dependencies_opts {
-	my ($meta, $phase, $type) = @_;
+	my ($meta, $phases, $type) = @_;
 
-	my $reqs = $meta->effective_prereqs->requirements_for($phase, $type);
-	for my $module ($reqs->required_modules) {
-		my $version;
-		if ($module eq 'perl') {
-			$version = $];
-		}
-		else {
-			my $metadata = Module::Metadata->new_from_module($module);
-			fail("Module '$module' is not installed"), next if not defined $metadata;
-			$version = eval { $metadata->version };
-		}
-		fail("Missing version info for module '$module'"), next if not $version;
-		fail(sprintf 'Version %s of module %s is not in range \'%s\'', $version, $module, $reqs->as_string_hash->{$module}), next if not $reqs->accepts_module($module, $version);
-		pass("$module $version is present");
+	my $reqs = requirements_for($meta, $phases, $type);
+	my $raw = $reqs->as_string_hash;
+	my $ret = check_requirements($reqs, $type);
+
+	for my $module (keys %{$ret}) {
+		$builder->ok(!defined $ret->{$module}, "$module satisfies '" . $raw->{$module} . "'") or $builder->diag($ret->{$module});
 	}
 	return;
 }
 
 1;
 
+#ABSTRACT: Check for presence of dependencies
+
 
 
 =pod
@@ -55,7 +53,7 @@ Test::CheckDeps - Check for presence of dependencies
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
@@ -87,5 +85,3 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
-#ABSTRACT: Check for presence of dependencies
-
